Page 10 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 10

Home

    Ancient historians have told us that, at the height of
    its glory, Babylon was protected by 60 miles of walls, 15
    miles on each side. The walls were 300 feet high, 80 feet
    thick at their base and sunk to a depth of 35 feet below

    Arn.

    ground. On the walls were 250 towers with housing for
    military personnel. Through 100 brass gates passed
    traffic in and out of the city. Deep and wide canals
    surrounded the outside of the walls.

    of two parallel walls each 20 feet thick. The inner wall
    was also protected by a canal. A quarter of a mile farther
    in from the inner wall lay the city. In times of ancient
    warfare it was simply impregnable. Excavations of recent
    years seem to verify the fabulous accounts of historians.
    It was a beautiful city with the Euphrates River flowing
    through the center. Its hanging gardens were one of the
    Seven Wonders of the ancient world. Isaiah called it,

    "Babylon, the glory of kingdoms,..." Isaiah 13:19.

    The Old Testament prophet Jeremiah lived during the
    time of Nebuchadnezzar. During this period the moral
    level of Judah had fallen so low that the prophet
    repeatedly cried out against the evil of his day,
    prophesying the coming captivity of the nation of Judah
    by the Babylonians.

    Eventually the predictions of Jeremiah did come to
    pass as recorded in II Kings chapter 24:

    11 And Nebuchadnezzar King of Babylon came against
    the city, and his servants did besiege it.

    Ancient Babylon

    Inside the outer wall there was another barrier made